Using the bio3d::write.pdb() function this function writes a PDB
file for the conserved water oxygen atoms with the percentage of structures
with a water participting in the cluster (written to the occupancy column)
and the calculated B-value -- using the rmsf of the waters in the cluster
-- for the waters participating in the cluster (written to the B-value
column). This function is called from the ConservedWaters() function.
All water molecules will include the water's oxygen atom (elety), be
assigned the residue name (resid) HOH, and the chain (chain) A
while the atom number (eleno) and residue number (resno) both start at
1.
NOTE: This is a non-public function.